--[[
	ImprovedRepairCosts.lua
	--- IN DEVELOPMENT ---
	version: 0.1.0.0
	date: 21/12/14
	author: BigBlueHH
]]


ImprovedRepairCosts = {}

-- default = 1, 50% = 0.5, 
ImprovedRepairCosts.damageMultiplier = 0.5
ImprovedRepairCosts.priceMultiplier = 0.5

-- ###############################################################
-- if you do not know what you do, please do not change any values
-- ###############################################################
ImprovedRepairCosts.balanceMultiplier = 0.1

function ImprovedRepairCosts.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Wearable, specializations)
end


function ImprovedRepairCosts.registerOverwrittenFunctions(vehicleType)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "getRepairPrice", ImprovedRepairCosts.getRepairPrice)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "getDamageAmount", ImprovedRepairCosts.getDamageAmount)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "getVehicleDamage", ImprovedRepairCosts.getVehicleDamage)	
end


function ImprovedRepairCosts:getRepairPrice(sFunc)
	local defaultCosts = sFunc(self)
	local multiplier = 1
	local balanceMultiplier = ImprovedRepairCosts.balanceMultiplier
	if self.lifetime ~= nil and self.lifetime ~= 0 then
		local ageMultiplier = 0.3 * math.min(self.age*balanceMultiplier/self.lifetime, 1)
		local operatingTime = self.operatingTime / (1000*60*60)
		local operatingTimeMultiplier =  0.7 * math.min(operatingTime*balanceMultiplier / (self.lifetime*EconomyManager.LIFETIME_OPERATINGTIME_RATIO), 1)		
		multiplier = 1 + ageMultiplier + operatingTimeMultiplier
	end
	return defaultCosts * multiplier * ImprovedRepairCosts.priceMultiplier
end


function ImprovedRepairCosts:getDamageAmount(sFunc)
	local defaultDamageAmount = sFunc(self)
	return defaultDamageAmount * ImprovedRepairCosts.damageMultiplier
end


function ImprovedRepairCosts:getVehicleDamage(sFunc)
	local defaultVehicleDamage = sFunc(self)
	return defaultVehicleDamage * ImprovedRepairCosts.damageMultiplier
end
